<?php

if (! defined('ABSPATH') ) {
	exit; // restict for direct access
}

if (! class_exists('Admin_Class_Addify_Customer_And_Role_Pricing') ) {

	class Admin_Class_Addify_Customer_And_Role_Pricing extends Addify_B2B_Plugin {
	


		public function __construct() {

			add_action('admin_enqueue_scripts', array( $this, 'csp_admin_assets' ));
			// Product Level
			// Create the custom tab
			add_filter('woocommerce_product_data_tabs', array( $this, 'create_csp_tab' ));
			// Add the custom fields
			add_action('woocommerce_product_data_panels', array( $this, 'display_csp_fields' ));
			// Save the custom fields
			add_action('woocommerce_process_product_meta', array( $this, 'save_csp_fields' ));

			// For Variable Products
			add_action('woocommerce_product_after_variable_attributes', array( $this, 'csp_variable_fields' ), 10, 3);
			add_action('woocommerce_save_product_variation', array( $this, 'csp_save_custom_field_variations' ), 10, 2);

			// Rule Based
			add_action('add_meta_boxes', array( $this, 'csp_add_custom_meta_box' ));
			add_action('save_post', array( $this, 'csp_add_custom_meta_save' ));
			add_filter('manage_csp_rules_posts_columns', array( $this, 'csp_rules_custom_columns' ));
			add_action('manage_csp_rules_posts_custom_column', array( $this, 'csp_rules_custom_column' ), 10, 2);

			add_action('wp_ajax_cspsearchProducts', array( $this, 'cspsearchProducts' ));
			add_action('wp_ajax_cspsearchUsers', array( $this, 'cspsearchUsers' ));

			//Add Role Base Pring meta to product export

			add_filter('woocommerce_product_export_column_names', array($this, 'csp_add_export_column' ));
			add_filter('woocommerce_product_export_product_default_columns', array($this, 'csp_add_export_column' ));

			add_filter('woocommerce_product_export_product_column__cus_base_price', array($this, 'csp_add_export_data_cus_base'), 10, 2);
			add_filter('woocommerce_product_export_product_column__role_base_price', array($this, 'csp_add_export_data_role_base'), 10, 2);

		}

		public function csp_add_export_column( $columns ) {

			// column slug => column name
			$columns['_cus_base_price']  = 'Customer Based Pricing';
			$columns['_role_base_price'] = 'Role Based Pricing';

			return $columns;
		}
		

		public function csp_add_export_data_cus_base( $value, $product ) {
			
			$value = serialize($product->get_meta('_cus_base_price', true, 'edit'));
			return $value;
		}

		public function csp_add_export_data_role_base( $value, $product ) {
			$value = serialize($product->get_meta('_role_base_price', true, 'edit'));
			return $value;
		}

		public function csp_admin_assets() {

			$screen = get_current_screen();

			if ('toplevel_page_addify-b2b' == $screen->id || 'edit-csp_rules' == $screen->id || 'csp_rules' == $screen->id || 'edit-product' == $screen->id || 'product' == $screen->id ) {

				wp_enqueue_style('addify_csp_admin_css', plugins_url('../assets/css/addify_csp_admin_css.css', __FILE__), false, '1.1');
				wp_enqueue_script('addify_csp_admin_js', plugins_url('../assets/js/addify_csp_admin_js.js', __FILE__), false, '1.1');
				$csp_data = array(
				'admin_url' => admin_url('admin-ajax.php'),
				'nonce'     => wp_create_nonce('afrolebase-ajax-nonce'),

				);
				wp_localize_script('addify_csp_admin_js', 'csp_php_vars', $csp_data);
				// select2 css and js
				wp_enqueue_script('jquery');
				wp_enqueue_style('addify_ps-select2-css', 'https://cdnjs.cloudflare.com/ajax/libs/select2/4.0.6-rc.0/css/select2.min.css', false, '1.0');
				wp_enqueue_style('addify_ps-select2-bscss', 'https://cdnjs.cloudflare.com/ajax/libs/select2/3.5.2/select2-bootstrap.css', false, '1.0');
				wp_enqueue_script('addify_ps-select2-js', 'https://cdnjs.cloudflare.com/ajax/libs/select2/4.0.6-rc.0/js/select2.min.js', false, '1.0');
			}

		}

		public function create_csp_tab( $tabs ) {
			$tabs['addify_csp_customer'] = array(
			'label'    => esc_html__('Role Based Pricing(By Customers)', 'addify_b2b'), // The name of your panel
			'target'   => 'addify_csp_panel_customer', // Will be used to create an anchor link so needs to be unique
			'class'    => array( 'addify_csp_tab', 'show_if_simple' ), // Class for your panel tab - helps hide/show depending on product type
			'priority' => 80, // Where your panel will appear. By default, 70 is last item
			);

			$tabs['addify_csp_role'] = array(
			'label'    => esc_html__('Role Based Pricing(By User Roles)', 'addify_b2b'), // The name of your panel
			'target'   => 'addify_csp_panel_role', // Will be used to create an anchor link so needs to be unique
			'class'    => array( 'addify_csp_tab', 'show_if_simple' ), // Class for your panel tab - helps hide/show depending on product type
			'priority' => 80, // Where your panel will appear. By default, 70 is last item
			);
			return $tabs;
		}

		public function display_csp_fields() {

			global $post;

			$cus_base_prices  = get_post_meta($post->ID, '_cus_base_price', true);
			$role_base_prices = get_post_meta($post->ID, '_role_base_price', true);
			wp_nonce_field('csp_nonce_action', 'csp_nonce_field');

			include AFB2B_PLUGIN_DIR . 'includes/csp_product_level.php';

		}

		public function csp_variable_fields( $loop, $variation_data, $variation ) {

			$cus_base_prices  = get_post_meta($variation->ID, '_cus_base_price', true);
			$role_base_prices = get_post_meta($variation->ID, '_role_base_price', true);
			wp_nonce_field('csp_nonce_action', 'csp_nonce_field');

			include AFB2B_PLUGIN_DIR . 'includes/csp_product_level_variable_product.php';

		}

		public function save_csp_fields( $post_id ) {

			$product = wc_get_product($post_id);

			if ('variable' != $product->get_type() ) {

				if (isset($_POST['cus_base_price']) ) {

					if (! empty($_REQUEST['csp_nonce_field']) ) {

						$retrieved_nonce = sanitize_text_field($_REQUEST['csp_nonce_field']);
					} else {
						$retrieved_nonce = 0;
					}

					if (! wp_verify_nonce($retrieved_nonce, 'csp_nonce_action') ) {

						   die('Failed security check');
					}

					$cus_base_price = sanitize_meta('', $_POST['cus_base_price'], '');
				} else {
					$cus_base_price = '';
				}

				if (! empty($cus_base_price) ) {

					$product->update_meta_data('_cus_base_price', $cus_base_price);
				} else {

					$product->delete_meta_data('_cus_base_price');
				}

				// role based

				if (isset($_POST['role_base_price']) ) {

					$role_base_price = sanitize_meta('', $_POST['role_base_price'], '');
				} else {
					$role_base_price = '';
				}

				if (! empty($role_base_price) ) {

					$product->update_meta_data('_role_base_price', $role_base_price);
				} else {

					$product->delete_meta_data('_role_base_price');
				}
				

				$product->save();
			}

		}

		public function csp_save_custom_field_variations( $variation_id, $i ) {

			if (isset($_POST['cus_base_price'][ $variation_id ]) ) {

				if (! empty($_REQUEST['csp_nonce_field']) ) {

					$retrieved_nonce = sanitize_text_field($_REQUEST['csp_nonce_field']);
				} else {
					$retrieved_nonce = 0;
				}

				if (! wp_verify_nonce($retrieved_nonce, 'csp_nonce_action') ) {

					die('Failed security check');
				}

				$cus_base_price = sanitize_meta('', $_POST['cus_base_price'][ $variation_id ], '');
			} else {
				$cus_base_price = '';
			}

			if ('' != $cus_base_price ) {
				update_post_meta($variation_id, '_cus_base_price', $cus_base_price);
			} else {
				update_post_meta($variation_id, '_cus_base_price', '');
			}

			//role base
			if (isset($_POST['role_base_price'][ $variation_id ]) ) {

				$role_base_price = sanitize_meta('', $_POST['role_base_price'][ $variation_id ], '');
			} else {
				$role_base_price = '';
			}

			if ('' != $role_base_price ) {
				update_post_meta($variation_id, '_role_base_price', $role_base_price);
			} else {
				update_post_meta($variation_id, '_role_base_price', '');
			}

			

		}

		public function csp_add_custom_meta_box() {

			add_meta_box('csp-meta-box', esc_html__('Rule Details', 'addify_b2b'), array( $this, 'csp_meta_box_callback' ), 'csp_rules', 'normal', 'high', null);
		}

		public function csp_meta_box_callback() {

			global $post;
			wp_nonce_field('csp_nonce_action', 'csp_nonce_field');
			$rcus_base_price  = get_post_meta($post->ID, 'rcus_base_price', true);
			$rrole_base_price = get_post_meta($post->ID, 'rrole_base_price', true);

			$csp_applied_on_categories = get_post_meta($post->ID, 'csp_applied_on_categories', true);

			include AFB2B_PLUGIN_DIR . 'includes/csp_rule_level.php';

		}

		public function csp_add_custom_meta_save( $post_id ) {

			// Bail if we're doing an auto save
			if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) {
				return;
			}

			// if our current user can't edit this post, bail
			if (! current_user_can('edit_posts') ) {
				return;
			}

			if (isset($_POST['csp_rules']) ) {

				if (! empty($_REQUEST['csp_nonce_field']) ) {

					$retrieved_nonce = sanitize_text_field($_REQUEST['csp_nonce_field']);
				} else {
					$retrieved_nonce = 0;
				}

				if (! wp_verify_nonce($retrieved_nonce, 'csp_nonce_action') ) {

					die('Failed security check');
				}
			}

			if (! empty($_SESSION['allfetchedrules']) ) {

				session_unset($_SESSION['allfetchedrules']);
			}

			remove_action('save_post', array( $this, 'csp_add_custom_meta_save' ));

			if (isset($_POST['csp_rule_priority']) ) {
				wp_update_post(
					array(
					'ID'         => intval($post_id),
					'menu_order' => sanitize_text_field($_POST['csp_rule_priority']),
					)
				);
			}

			add_action('save_post', array( $this, 'csp_add_custom_meta_save' ));

			if (isset($_POST['csp_apply_on_all_products']) ) {
				update_post_meta($post_id, 'csp_apply_on_all_products', sanitize_text_field($_POST['csp_apply_on_all_products']));
			} else {
				delete_post_meta($post_id, 'csp_apply_on_all_products', '');
			}

			if (isset($_POST['csp_applied_on_products']) ) {
				update_post_meta($post_id, 'csp_applied_on_products', sanitize_meta('', $_POST['csp_applied_on_products'], ''));
			} else {
				delete_post_meta($post_id, 'csp_applied_on_products');
			}

			if (isset($_POST['csp_applied_on_categories']) ) {
				update_post_meta($post_id, 'csp_applied_on_categories', sanitize_meta('', $_POST['csp_applied_on_categories'], ''));
			} else {
				delete_post_meta($post_id, 'csp_applied_on_categories');
			}

			if (isset($_POST['rcus_base_price']) ) {
				update_post_meta($post_id, 'rcus_base_price', sanitize_meta('', $_POST['rcus_base_price'], ''));
			} else {
				delete_post_meta($post_id, 'rcus_base_price');
			}

			if (isset($_POST['rrole_base_price']) ) {
				update_post_meta($post_id, 'rrole_base_price', sanitize_meta('', $_POST['rrole_base_price'], ''));
			} else {
				delete_post_meta($post_id, 'rrole_base_price');
			}

			

		}

		public function csp_rules_custom_columns( $columns ) {

			unset($columns['date']);
			$columns['csp_rule_priority'] = esc_html__('Rule Priority', 'addify_b2b');
			$columns['date']              = esc_html__('Date Published', 'addify_b2b');

			return $columns;

		}

		public function csp_rules_custom_column( $column, $post_id ) {

			$postt = get_post($post_id);

			switch ( $column ) {
				case 'csp_rule_priority':
					echo esc_attr($postt->menu_order);
					break;
			}
		}


		public function cspsearchProducts() {

			if (isset($_POST['nonce']) && '' != $_POST['nonce'] ) {

				$nonce = sanitize_text_field($_POST['nonce']);
			} else {
				$nonce = 0;
			}

			if (isset($_POST['q']) && '' != $_POST['q'] ) {

				if (! wp_verify_nonce($nonce, 'afrolebase-ajax-nonce') ) {

					die('Failed ajax security check!');
				}

				$pro = sanitize_text_field($_POST['q']);

			} else {

				$pro = '';

			}

			$data_array = array();
			$args       = array(
			'post_type'   => array( 'product' ),
			'post_status' => 'publish',
			'numberposts' => 50,
			's'           => $pro,
			);
			$pros       = get_posts($args);

			if (! empty($pros) ) {

				foreach ( $pros as $proo ) {

					$title        = ( mb_strlen($proo->post_title) > 50 ) ? mb_substr($proo->post_title, 0, 49) . '...' : $proo->post_title;
					$data_array[] = array( $proo->ID, $title ); // array( Post ID, Post Title )
				}
			}

			echo json_encode($data_array);

			die();
		}

		public function cspsearchUsers() {

			if (isset($_POST['nonce']) && '' != $_POST['nonce'] ) {

				$nonce = sanitize_text_field($_POST['nonce']);
			} else {
				$nonce = 0;
			}

			if (isset($_POST['q']) && '' != $_POST['q'] ) {

				if (! wp_verify_nonce($nonce, 'afrolebase-ajax-nonce') ) {

					die('Failed ajax security check!');
				}

				$pro = sanitize_text_field($_POST['q']);

			} else {

				$pro = '';

			}

			$data_array  = array();
			$users       = new WP_User_Query(
				array(
				'search'         => '*' . esc_attr($pro) . '*',
				'search_columns' => array(
						'user_login',
						'user_nicename',
						'user_email',
						'user_url',
				),
				)
			);
			$users_found = $users->get_results();

			if (! empty($users_found) ) {

				foreach ( $users_found as $proo ) {

					$title        = $proo->display_name . '(' . $proo->user_email . ')';
					$data_array[] = array( $proo->ID, $title ); // array( User ID, User name and email )
				}
			}

			echo json_encode($data_array);

			die();

		}


	}

	new Admin_Class_Addify_Customer_And_Role_Pricing();

}
